%global gem_name geoip

Name: rubygem-%{gem_name}
Version: 1.3.3
Release: 1%{?dist}
Summary: Search a GeoIP database for an IP address
Group: Development/Languages
License: LGPLv2+
URL: http://github.com/cjheath/geoip
Source0: https://rubygems.org/gems/%{gem_name}-%{version}.gem
# Upstream does not include full LGPLv2+ text.
# Requested at https://github.com/cjheath/geoip/issues/34
Requires: ruby(release)
Requires: ruby(rubygems)
BuildRequires: rubygems-devel
BuildRequires: rubygem(minitest)
BuildArch: noarch
Provides: rubygem(%{gem_name}) = %{version}

# The ruby(release) package already provides a usable Ruby interpreter.
# Filter the extra /usr/bin/ruby requirement here.
%global __requires_exclude ^/usr/bin/ruby$

%description
GeoIP searches a GeoIP database for a given host or IP address, and
returns information about the country where the IP address is allocated,
and the city, ISP and other information, if you have that database version.


%package doc
Summary: Documentation for %{name}
Group: Documentation
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Documentation for %{name}

%prep
gem unpack %{SOURCE0}

%setup -q -D -T -n  %{gem_name}-%{version}

gem spec %{SOURCE0} -l --ruby > %{gem_name}.gemspec

# Fix shebang
sed -i -e 's|#!/usr/bin/env ruby|#!/usr/bin/ruby|' bin/%{gem_name}

# Clean up development-only files
for dir in config script website; do
  rm -r $dir
  # ...and delete the corresponding entries from the gemspec
  sed -i -e "s/\"${dir}\/[^\"]*\",*//g" %{gem_name}.gemspec
done


%build
# Create the gem as gem install only works on a gem file
gem build %{gem_name}.gemspec

# %%gem_install compiles any C extensions and installs the gem into ./%%gem_dir
# by default, so that we can move it into the buildroot in %%install
%gem_install

# remove unecessary gemspec
pushd .%{gem_instdir}
  rm %{gem_name}.gemspec
popd

%install
mkdir -p %{buildroot}%{gem_dir}
cp -pa .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

mkdir -p %{buildroot}%{_bindir}
cp -pa .%{_bindir}/* \
        %{buildroot}%{_bindir}/

find %{buildroot}%{gem_instdir}/bin -type f | xargs chmod a+x

%check
pushd .%{gem_instdir}
  testrb -Ilib test
popd

%files
%dir %{gem_instdir}
%doc %{gem_instdir}/LICENSE
%exclude %{gem_instdir}/.*
%{_bindir}/%{gem_name}
%{gem_instdir}/bin
%{gem_instdir}/data
%{gem_libdir}
%exclude %{gem_cache}
%{gem_spec}

%files doc
%doc %{gem_docdir}
%doc %{gem_instdir}/README.rdoc
%doc %{gem_instdir}/History.rdoc
%{gem_instdir}/Rakefile
%{gem_instdir}/test

%changelog
* Thu Oct 24 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 1.3.3-1
- Update to 1.3.3

* Mon Oct 07 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 1.3.2-1
- Update to 1.3.2
- Drop our LGPL license file, since upstream ships their own

* Fri Sep 13 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 1.3.0-2
- Fix issues in package review (RHBZ #993482). Thanks jvcelak
- Fix LICENSE file permissions
- Simplify Requires and BuildRequires

* Thu Sep 12 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 1.3.0-1
- Update to 1.3.0
- Include LGPLv2+ license text

* Mon Aug 05 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 1.2.2-1
- Initial package
